<?php

/**
 * @file
 * Include file for the vitals module.
 */

/**
 * Gets site status.
 */
function vitals_get_status() {
  $info = array(
    'php_version' => vitals_get_php_version(),
    'cms_version' => vitals_get_drupal_version(),
    'updates' => vitals_get_updates(),
  );

  return $info;
}

/**
 * Gets the PHP version of the site.
 */
function vitals_get_php_version() {
  return sprintf(
    '%d.%d.%d',
    PHP_MAJOR_VERSION,
    PHP_MINOR_VERSION,
    PHP_RELEASE_VERSION
  );
}

/**
 * Gets the Drupal version of the site.
 */
function vitals_get_drupal_version() {
  return VERSION;
}

/**
 * Gets version data for installed modules.
 */
function vitals_get_extensions() {
  $extensions = array();

  if ($available = update_get_available(TRUE)) {
    module_load_include('inc', 'update', 'update.compare');
    $extensions = update_calculate_project_data($available);
  }

  return $extensions;
}

/**
 * Gets version data for installed modules.
 */
function vitals_get_updates() {
  $extensions = vitals_get_extensions();

  $updates = array();
  $security_updates = array();

  foreach ($extensions as $extension) {
    $status = $extension['status'];
    $machine_name = $extension['name'];
    $recommended_version = $extension['recommended'];

    switch ($status) {
      case UPDATE_NOT_SECURE:
      case UPDATE_REVOKED:
      case UPDATE_NOT_SUPPORTED:
        $security_updates[$machine_name] = $recommended_version;
        $updates[$machine_name] = $recommended_version;
        break;

      case UPDATE_NOT_CURRENT:
        $updates[$machine_name] = $recommended_version;
        break;
    }
  }

  $update_data = array(
    'pending_updates' => $updates,
    'security_updates' => $security_updates,
  );

  return $update_data;
}

/**
 * Gets a generated authentication token.
 */
function vitals_generate_token() {
  return bin2hex(random_bytes(64));
}

/**
 * Gets the vitals path for use with l().
 */
function vitals_get_path() {
  return sprintf('%s/%s', 'vitals', variable_get('vitals_token'));
}
